from setuptools import setup

setup(name='dist_kanishka',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['dist_kanishka'],
      author = 'Kanishka Dandeniya',
      author_email = 'kanishka.d@eng.pdn.ac.lk',
      zip_safe=False)
